package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcDataSource;

/**
 * 数据来源Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcDataSourceMapper 
{
    /**
     * 查询数据来源
     * 
     * @param id 数据来源主键
     * @return 数据来源
     */
    public TcDataSource selectTcDataSourceById(Long id);

    /**
     * 查询数据来源列表
     * 
     * @param tcDataSource 数据来源
     * @return 数据来源集合
     */
    public List<TcDataSource> selectTcDataSourceList(TcDataSource tcDataSource);

    /**
     * 新增数据来源
     * 
     * @param tcDataSource 数据来源
     * @return 结果
     */
    public int insertTcDataSource(TcDataSource tcDataSource);

    /**
     * 修改数据来源
     * 
     * @param tcDataSource 数据来源
     * @return 结果
     */
    public int updateTcDataSource(TcDataSource tcDataSource);

    /**
     * 删除数据来源
     * 
     * @param id 数据来源主键
     * @return 结果
     */
    public int deleteTcDataSourceById(Long id);

    /**
     * 批量删除数据来源
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcDataSourceByIds(Long[] ids);
}
