package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcDataSource;
import com.ruoyi.zongzhi.service.ITcDataSourceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 数据来源Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/source")
@Api(tags = " 数据来源")
public class TcDataSourceController extends BaseController
{
    @Autowired
    private ITcDataSourceService tcDataSourceService;

    /**
     * 查询数据来源列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcDataSource tcDataSource)
    {
        startPage();
        List<TcDataSource> list = tcDataSourceService.selectTcDataSourceList(tcDataSource);
        return getDataTable(list);
    }

    /**
     * 导出数据来源列表
     */


    @PostMapping("/export")
    public void export(HttpServletResponse response, TcDataSource tcDataSource)
    {
        List<TcDataSource> list = tcDataSourceService.selectTcDataSourceList(tcDataSource);
        ExcelUtil<TcDataSource> util = new ExcelUtil<TcDataSource>(TcDataSource.class);
        util.exportExcel(response, list, "数据来源数据");
    }

    /**
     * 获取数据来源详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcDataSourceService.selectTcDataSourceById(id));
    }

    /**
     * 新增数据来源
     */
    @PostMapping
    public AjaxResult add(@RequestBody TcDataSource tcDataSource)
    {
        tcDataSource.setIsStatus(true);
        return toAjax(tcDataSourceService.insertTcDataSource(tcDataSource));
    }

    /**
     * 修改数据来源
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcDataSource tcDataSource)
    {
        return toAjax(tcDataSourceService.updateTcDataSource(tcDataSource));
    }

    /**
     * 删除数据来源
     */


	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcDataSourceService.deleteTcDataSourceByIds(ids));
    }
}
